summaryrefslogtreecommitdiff
path: root/src/testing/testing_api_cmd_auditor_del.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/testing/testing_api_cmd_auditor_del.c')
-rw-r--r--src/testing/testing_api_cmd_auditor_del.c9
1 files changed, 6 insertions, 3 deletions
diff --git a/src/testing/testing_api_cmd_auditor_del.c b/src/testing/testing_api_cmd_auditor_del.c
index de03d1632..5bf77bb50 100644
--- a/src/testing/testing_api_cmd_auditor_del.c
+++ b/src/testing/testing_api_cmd_auditor_del.c
@@ -62,13 +62,16 @@ struct AuditorDelState
* if the response code is acceptable.
*
* @param cls closure.
* @param hr HTTP response details
*/
static void
-auditor_del_cb (void *cls,
- const struct TALER_EXCHANGE_HttpResponse *hr)
+auditor_del_cb (
+ void *cls,
+ const struct TALER_EXCHANGE_ManagementAuditorDisableResponse *adr)
+
{
struct AuditorDelState *ds = cls;
+ const struct TALER_EXCHANGE_HttpResponse *hr = &adr->hr;
ds->dh = NULL;
if (ds->expected_response_code != hr->http_status)
@@ -62,13 +62,16 @@ struct AuditorDelState
*
* @param cls closure.
- * @param hr HTTP response details
+ * @param adr response details
*/
static void